@@ -1,8 +1,8 @@
 # --
-# Kernel/Language/sk_SK.pm - provides sk_SK language translation
+# Kernel/Language/sk_SK.pm - provides Slovak language translation
 # Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
 # --
-# $Id: sk_SK.pm,v 1.54 2009/07/13 09:49:47 martin Exp $
+# $Id: sk_SK.pm,v 1.55 2009/08/25 12:19:24 mb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.54 $) [1];
+$VERSION = qw($Revision: 1.55 $) [1];
 
 sub Data {
     my $Self = shift;
@@ -320,6 +320,7 @@ sub Data {
         'February' => '',
         'March' => '',
         'April' => '',
+        'May_long' => '',
         'June' => '',
         'July' => '',
         'August' => '',
@@ -1648,7 +1649,6 @@ sub Data {
         'Adresti' => 'Body',
         'SMIME riadenie' => 'Add Certificate',
         'Tlai' => 'Keywords',
-        'Sprva poslan' => 'Recipents',
         'riadenie balka' => 'Uninstall',
         'prida poznmku k poiadavke' => 'Inform Agent',
         'vyber prieinok' => 'SQL',
