@@ -2,7 +2,7 @@
 # Kernel/Modules/AgentTicketEmail.pm - to compose initial email to customer
 # Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketEmail.pm,v 1.94 2009/07/20 10:36:04 mh Exp $
+# $Id: AgentTicketEmail.pm,v 1.99 2009/08/25 14:32:55 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -24,7 +24,7 @@ use Kernel::System::State;
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.94 $) [1];
+$VERSION = qw($Revision: 1.99 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -217,7 +217,7 @@ sub Run {
 
             # run compose modules
             if (
-                ref( $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') ) eq
+                ref $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') eq
                 'HASH'
                 )
             {
@@ -226,22 +226,20 @@ sub Run {
                 for my $Job ( sort keys %Jobs ) {
 
                     # load module
-                    if ( $Self->{MainObject}->Require( $Jobs{$Job}->{Module} ) ) {
-                        my $Object
-                            = $Jobs{$Job}->{Module}->new( %{$Self}, Debug => $Self->{Debug}, );
-
-                        # get params
-                        my %GetParam;
-                        for ( $Object->Option( %GetParam, Config => $Jobs{$Job} ) ) {
-                            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
-                        }
-
-                        # run module
-                        $Object->Run( %GetParam, Config => $Jobs{$Job} );
-                    }
-                    else {
+                    if ( !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} ) ) {
                         return $Self->{LayoutObject}->FatalError();
                     }
+
+                    my $Object = $Jobs{$Job}->{Module}->new( %{$Self}, Debug => $Self->{Debug}, );
+
+                    # get params
+                    my %GetParam;
+                    for ( $Object->Option( %GetParam, Config => $Jobs{$Job} ) ) {
+                        $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
+                    }
+
+                    # run module
+                    $Object->Run( %GetParam, Config => $Jobs{$Job} );
                 }
             }
 
@@ -590,28 +588,31 @@ sub Run {
             for my $Job ( sort keys %Jobs ) {
 
                 # load module
-                if ( $Self->{MainObject}->Require( $Jobs{$Job}->{Module} ) ) {
-                    my $Object = $Jobs{$Job}->{Module}->new( %{$Self}, Debug => $Self->{Debug}, );
-
-                    # get params
-                    for ( $Object->Option( %GetParam, Config => $Jobs{$Job} ) ) {
-                        $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
-                    }
-
-                    # run module
-                    $Object->Run( %GetParam, Config => $Jobs{$Job} );
-
-                    # ticket params
-                    %ArticleParam = (
-                        %ArticleParam, $Object->ArticleOption( %GetParam, Config => $Jobs{$Job} )
-                    );
-
-                    # get errors
-                    %Error = ( %Error, $Object->Error( %GetParam, Config => $Jobs{$Job} ) );
-                }
-                else {
+                if ( !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} ) ) {
                     return $Self->{LayoutObject}->FatalError();
                 }
+
+                my $Object = $Jobs{$Job}->{Module}->new( %{$Self}, Debug => $Self->{Debug}, );
+
+                # get params
+                for ( $Object->Option( %GetParam, Config => $Jobs{$Job} ) ) {
+                    $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
+                }
+
+                # run module
+                $Object->Run( %GetParam, Config => $Jobs{$Job} );
+
+                # ticket params
+                %ArticleParam = (
+                    %ArticleParam,
+                    $Object->ArticleOption( %GetParam, Config => $Jobs{$Job} ),
+                );
+
+                # get errors
+                %Error = (
+                    %Error,
+                    $Object->Error( %GetParam, Config => $Jobs{$Job} ),
+                );
             }
         }
 
@@ -914,9 +915,7 @@ sub Run {
             }
 
             # get redirect screen
-            my $NextScreen = $Self->{UserCreateNextMask}
-                || $Self->{ConfigObject}->Get('PreferencesGroups')->{CreateNextMask}->{DataSelected}
-                || 'AgentTicketEmail';
+            my $NextScreen = $Self->{UserCreateNextMask} || 'AgentTicketEmail';
 
             # redirect
             return $Self->{LayoutObject}->Redirect(
@@ -928,11 +927,15 @@ sub Run {
         }
     }
     elsif ( $Self->{Subaction} eq 'AJAXUpdate' ) {
-        my $Dest         = $Self->{ParamObject}->GetParam( Param => 'Dest' ) || '';
+        my $Dest = $Self->{ParamObject}->GetParam( Param => 'Dest' ) || '';
         my $CustomerUser = $Self->{ParamObject}->GetParam( Param => 'SelectedCustomerUser' );
-        my $QueueID      = '';
+
+        # get From based on selected queue
+        my $QueueID = '';
         if ( $Dest =~ /^(\d{1,100})\|\|.+?$/ ) {
             $QueueID = $1;
+            my %Queue = $Self->{QueueObject}->GetSystemAddress( QueueID => $QueueID );
+            $GetParam{From} = $Queue{Email};
         }
 
         # get list type
@@ -975,7 +978,7 @@ sub Run {
         );
 
         # get free text config options
-        my @TicketFreeTextConfig = ();
+        my @ExtendedData = ();
         for ( 1 .. 16 ) {
             my $ConfigKey = $Self->{TicketObject}->TicketFreeTextGet(
                 TicketID => $Self->{TicketID},
@@ -986,7 +989,7 @@ sub Run {
             );
             if ($ConfigKey) {
                 push(
-                    @TicketFreeTextConfig,
+                    @ExtendedData,
                     {
                         Name        => "TicketFreeKey$_",
                         Data        => $ConfigKey,
@@ -1005,7 +1008,7 @@ sub Run {
             );
             if ($ConfigValue) {
                 push(
-                    @TicketFreeTextConfig,
+                    @ExtendedData,
                     {
                         Name        => "TicketFreeText$_",
                         Data        => $ConfigValue,
@@ -1016,6 +1019,40 @@ sub Run {
                 );
             }
         }
+
+        # run compose modules
+        if ( ref $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') eq 'HASH' ) {
+            my %Jobs = %{ $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleComposeModule') };
+            for my $Job ( sort keys %Jobs ) {
+
+                # load module
+                next if !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} );
+
+                my $Object = $Jobs{$Job}->{Module}->new( %{$Self}, Debug => $Self->{Debug}, );
+
+                # get params
+                for ( $Object->Option( %GetParam, Config => $Jobs{$Job} ) ) {
+                    $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
+                }
+
+                # run module
+                my %Data = $Object->Data( %GetParam, Config => $Jobs{$Job} );
+
+                my $Key = $Object->Option( %GetParam, Config => $Jobs{$Job} );
+                if ($Key) {
+                    push(
+                        @ExtendedData,
+                        {
+                            Name        => $Key,
+                            Data        => \%Data,
+                            SelectedID  => $GetParam{$Key},
+                            Translation => 1,
+                            Max         => 100,
+                        }
+                    );
+                }
+            }
+        }
         my $JSON = $Self->{LayoutObject}->BuildJSON(
             [
                 {
@@ -1072,7 +1109,7 @@ sub Run {
                     Translation  => 1,
                     Max          => 100,
                 },
-                @TicketFreeTextConfig,
+                @ExtendedData,
             ],
         );
         return $Self->{LayoutObject}->Attachment(
@@ -1384,6 +1421,8 @@ sub _MaskEmailNew {
                     'PriorityID',
                     'ServiceID',
                     'SLAID',
+                    'SignKeyID',
+                    'CryptKeyID',
                     'TicketFreeText1',
                     'TicketFreeText2',
                     'TicketFreeText3',
@@ -1400,6 +1439,9 @@ sub _MaskEmailNew {
                     'TicketFreeText14',
                     'TicketFreeText15',
                     'TicketFreeText16',
+                    'To',
+                    'Cc',
+                    'Bcc',
                 ],
                 Depend => [
                     'Dest',
@@ -1408,6 +1450,8 @@ sub _MaskEmailNew {
                     'PriorityID',
                     'ServiceID',
                     'SLAID',
+                    'SignKeyID',
+                    'CryptKeyID',
                     'OwnerAll',
                     'ResponsibleAll',
                     'TicketFreeText1',
@@ -1426,6 +1470,9 @@ sub _MaskEmailNew {
                     'TicketFreeText14',
                     'TicketFreeText15',
                     'TicketFreeText16',
+                    'To',
+                    'Cc',
+                    'Bcc',
                 ],
                 Subaction => 'AJAXUpdate',
             },
@@ -1447,6 +1494,8 @@ sub _MaskEmailNew {
                     'PriorityID',
                     'ServiceID',
                     'SLAID',
+                    'SignKeyID',
+                    'CryptKeyID',
                     'TicketFreeText1',
                     'TicketFreeText2',
                     'TicketFreeText3',
@@ -1463,6 +1512,9 @@ sub _MaskEmailNew {
                     'TicketFreeText14',
                     'TicketFreeText15',
                     'TicketFreeText16',
+                    'To',
+                    'Cc',
+                    'Bcc',
                 ],
                 Depend => [
                     'Dest',
@@ -1471,6 +1523,8 @@ sub _MaskEmailNew {
                     'PriorityID',
                     'ServiceID',
                     'SLAID',
+                    'SignKeyID',
+                    'CryptKeyID',
                     'OwnerAll',
                     'ResponsibleAll',
                     'TicketFreeText1',
@@ -1489,6 +1543,9 @@ sub _MaskEmailNew {
                     'TicketFreeText14',
                     'TicketFreeText15',
                     'TicketFreeText16',
+                    'To',
+                    'Cc',
+                    'Bcc',
                 ],
                 Subaction => 'AJAXUpdate',
             },
@@ -1541,6 +1598,8 @@ sub _MaskEmailNew {
                     'PriorityID',
                     'ServiceID',
                     'SLAID',
+                    'SignKeyID',
+                    'CryptKeyID',
                     'TicketFreeText1',
                     'TicketFreeText2',
                     'TicketFreeText3',
@@ -1557,6 +1616,9 @@ sub _MaskEmailNew {
                     'TicketFreeText14',
                     'TicketFreeText15',
                     'TicketFreeText16',
+                    'To',
+                    'Cc',
+                    'Bcc',
                 ],
                 Depend => [
                     'Dest',
@@ -1565,6 +1627,8 @@ sub _MaskEmailNew {
                     'PriorityID',
                     'ServiceID',
                     'SLAID',
+                    'SignKeyID',
+                    'CryptKeyID',
                     'OwnerAll',
                     'ResponsibleAll',
                     'TicketFreeText1',
@@ -1583,6 +1647,9 @@ sub _MaskEmailNew {
                     'TicketFreeText14',
                     'TicketFreeText15',
                     'TicketFreeText16',
+                    'To',
+                    'Cc',
+                    'Bcc',
                 ],
                 Subaction => 'AJAXUpdate',
             },
@@ -1614,6 +1681,8 @@ sub _MaskEmailNew {
                     'PriorityID',
                     'ServiceID',
                     'SLAID',
+                    'SignKeyID',
+                    'CryptKeyID',
                     'TicketFreeText1',
                     'TicketFreeText2',
                     'TicketFreeText3',
@@ -1630,6 +1699,9 @@ sub _MaskEmailNew {
                     'TicketFreeText14',
                     'TicketFreeText15',
                     'TicketFreeText16',
+                    'To',
+                    'Cc',
+                    'Bcc',
                 ],
                 Depend => [
                     'Dest',
@@ -1638,6 +1710,8 @@ sub _MaskEmailNew {
                     'PriorityID',
                     'ServiceID',
                     'SLAID',
+                    'SignKeyID',
+                    'CryptKeyID',
                     'OwnerAll',
                     'ResponsibleAll',
                     'TicketFreeText1',
@@ -1656,6 +1730,9 @@ sub _MaskEmailNew {
                     'TicketFreeText14',
                     'TicketFreeText15',
                     'TicketFreeText16',
+                    'To',
+                    'Cc',
+                    'Bcc',
                 ],
                 Subaction => 'AJAXUpdate',
             },
@@ -1682,6 +1759,8 @@ sub _MaskEmailNew {
                     'PriorityID',
                     'ServiceID',
                     'SLAID',
+                    'SignKeyID',
+                    'CryptKeyID',
                     'TicketFreeText1',
                     'TicketFreeText2',
                     'TicketFreeText3',
@@ -1698,6 +1777,9 @@ sub _MaskEmailNew {
                     'TicketFreeText14',
                     'TicketFreeText15',
                     'TicketFreeText16',
+                    'To',
+                    'Cc',
+                    'Bcc',
                 ],
                 Depend => [
                     'Dest',
@@ -1706,6 +1788,8 @@ sub _MaskEmailNew {
                     'PriorityID',
                     'ServiceID',
                     'SLAID',
+                    'SignKeyID',
+                    'CryptKeyID',
                     'OwnerAll',
                     'ResponsibleAll',
                     'TicketFreeText1',
@@ -1724,6 +1808,9 @@ sub _MaskEmailNew {
                     'TicketFreeText14',
                     'TicketFreeText15',
                     'TicketFreeText16',
+                    'To',
+                    'Cc',
+                    'Bcc',
                 ],
                 Subaction => 'AJAXUpdate',
             },
@@ -1876,11 +1963,7 @@ sub _MaskEmailNew {
     }
 
     # show spell check
-    if (
-        $Self->{ConfigObject}->Get('SpellChecker')
-        && $Self->{LayoutObject}->{BrowserJavaScriptSupport}
-        )
-    {
+    if ( $Self->{LayoutObject}->{BrowserSpellChecker} ) {
         $Self->{LayoutObject}->Block(
             Name => 'SpellCheck',
             Data => {},
