@@ -1,5 +1,8 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Output/HTML/ArticleAttachmentDownload.pm
+# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# --
+# $Id: ArticleAttachmentDownload.pm,v 1.10 2009/08/28 16:32:58 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +14,9 @@ package Kernel::Output::HTML::ArticleAttachmentDownload;
 use strict;
 use warnings;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.10 $) [1];
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -31,10 +37,7 @@ sub Run {
     # check needed stuff
     for (qw(File Article)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
@@ -43,16 +46,15 @@ sub Run {
     my $Type = $Self->{ConfigObject}->Get('AttachmentDownloadType') || 'attachment';
 
     # if attachment will be forced to download, don't open a new download window!
-    my $Target = 'target="AttachmentWindow" ';
+    my $Target = '';
     if ( $Type =~ /inline/i ) {
         $Target = 'target="attachment" ';
     }
-
     return (
         %{ $Param{File} },
         Action => 'Download',
         Link =>
-            "\$Env{\"Baselink\"}Action=AgentTicketAttachment;ArticleID=$Param{Article}->{ArticleID};FileID=$Param{File}->{FileID}",
+            "\$Env{\"CGIHandle\"}/\$LQData{\"$Param{File}->{Filename}\"}?Action=AgentTicketAttachment&ArticleID=$Param{Article}->{ArticleID}&FileID=$Param{File}->{FileID}",
         Image  => 'disk-s.png',
         Target => $Target,
     );
