@@ -1,5 +1,8 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Kernel/Output/HTML/DashboardCalendar.pm
+# Copyright (C) 2001-2009 OTRS AG, http://otrs.org/
+# --
+# $Id: DashboardCalendar.pm,v 1.12 2009/08/18 12:52:53 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -11,6 +14,9 @@ package Kernel::Output::HTML::DashboardCalendar;
 use strict;
 use warnings;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.12 $) [1];
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -39,8 +45,7 @@ sub Config {
     my ( $Self, %Param ) = @_;
 
     return (
-        %{ $Self->{Config} },
-        CacheKey => 'Calendar' . $Self->{UserID} . '-' . $Self->{LayoutObject}->{UserLanguage},
+        %{ $Self->{Config} }
     );
 }
 
@@ -48,8 +53,6 @@ sub Run {
     my ( $Self, %Param ) = @_;
 
     # find tickets with reached times in near future
-    my $PendingReminderStateTypes = $Self->{ConfigObject}->Get('Ticket::PendingReminderStateType');
-
     my %Map = (
         Escalation => [
 
@@ -60,7 +63,7 @@ sub Run {
             {
 
                 # where escalation time reached
-                TicketEscalationTimeNewerMinutes => 15,
+                TicketEscalationTimeNewerMinutes => (15),
 
                 # sort
                 SortBy  => 'EscalationTime',
@@ -76,10 +79,10 @@ sub Run {
             {
 
                 # only pending reminder tickets
-                StateType => $PendingReminderStateTypes,
+                StateType => ['pending reminder'],
 
                 # where pending time reached in
-                TicketPendingTimeNewerMinutes => 15,
+                TicketPendingTimeNewerMinutes => (15),
 
                 # sort
                 SortBy  => 'PendingTime',
@@ -90,11 +93,6 @@ sub Run {
     my %Date;
     for my $Type ( sort keys %Map ) {
 
-        my $UID;
-        if ( $Self->{Config}->{OwnerOnly} ) {
-            $UID = $Self->{UserID};
-        }
-
         # search tickets
         my @TicketIDs = $Self->{TicketObject}->TicketSearch(
 
@@ -104,7 +102,6 @@ sub Run {
             Result     => 'ARRAY',
             Permission => $Self->{Config}->{Permission} || 'ro',
             UserID     => $Self->{UserID},
-            OwnerID    => $UID,
             Limit      => 25,
         );
 
@@ -112,9 +109,8 @@ sub Run {
         for my $TicketID (@TicketIDs) {
 
             my %Ticket = $Self->{TicketObject}->TicketGet(
-                TicketID      => $TicketID,
-                UserID        => $Self->{UserID},
-                DynamicFields => 0,
+                TicketID => $TicketID,
+                UserID   => $Self->{UserID},
             );
             my $TimeStamp;
             my $TimeTill;
@@ -127,7 +123,7 @@ sub Run {
                 # only show own pending tickets
                 next
                     if $Ticket{OwnerID} ne $Self->{UserID}
-                    && $Ticket{ResponsibleID} ne $Self->{UserID};
+                        && $Ticket{ResponsibleID} ne $Self->{UserID};
                 my $DestDate = $Self->{TimeObject}->SystemTime() + $Ticket{UntilTime};
                 $TimeTill  = $Ticket{UntilTime};
                 $TimeStamp = $Self->{TimeObject}->SystemTime2TimeStamp(
@@ -136,14 +132,14 @@ sub Run {
             }
 
             # remember attributes for content table
-            $Date{ $TimeStamp . '::' . $TicketID } = {
+            $Date{$TimeStamp} = {
                 Type         => $Type,
                 Text         => $Map{$Type}->[0],
                 Object       => 'Ticket',
                 ObjectID     => $Ticket{TicketID},
                 ObjectNumber => $Ticket{TicketNumber},
                 Title        => $Ticket{Title},
-                Link         => "Action=AgentTicketZoom;TicketID=$Ticket{TicketID}",
+                Link         => "Action=AgentTicketZoom&TicketID=$Ticket{TicketID}",
                 TimeStamp    => $TimeStamp,
                 TimeTill     => $TimeTill,
                 In           => $Self->{LayoutObject}->CustomerAge(
@@ -165,14 +161,6 @@ sub Run {
         );
     }
 
-    # fillup if no content exists
-    if ( !$Count ) {
-        $Self->{LayoutObject}->Block(
-            Name => 'ContentSmallCalendarOverviewNone',
-            Data => {},
-        );
-    }
-
     # render content
     my $Content = $Self->{LayoutObject}->Output(
         TemplateFile => 'AgentDashboardCalendarOverview',
@@ -181,6 +169,11 @@ sub Run {
         },
     );
 
+    # fillup if not content exists
+    if ( !%Date ) {
+        $Content = '$Text{"none"}';
+    }
+
     # return content
     return $Content;
 }
